@@ -459,15 +459,17 @@ class SpyderKernel(IPythonKernel):
         Set a backend for Matplotlib.
 
         backend: A parameter that can be passed to %matplotlib
-                 (e.g. inline or tk).
+                 (e.g. 'inline' or 'tk').
         """
         import traceback
         from IPython.core.getipython import get_ipython
 
-        generic_error = ("\n"
-                         "NOTE: The following error appeared when setting "
-                         "your Matplotlib backend\n\n"
-                         "{0}")
+        generic_error = (
+            "\n" + "="*73 + "\n"
+            "NOTE: The following error appeared when setting "
+            "your Matplotlib backend!!\n" + "="*73 + "\n\n"
+            "{0}"
+        )
 
         magic = 'pylab' if pylab else 'matplotlib'
 
@@ -480,11 +482,17 @@ class SpyderKernel(IPythonKernel):
             if "GUI eventloops" in str(err):
                 import matplotlib
                 previous_backend = matplotlib.get_backend()
-                error = ("\n"
-                         "NOTE: Spyder *can't* set your selected Matplotlib "
-                         "backend because there is a previous backend already "
-                         "in use.\n\n"
-                         "Your backend will be {0}".format(previous_backend))
+                if not backend in previous_backend.lower():
+                    # Only inform about an error if the user selected backend
+                    # and the one set by Matplotlib are different. Else this
+                    # message is very confusing.
+                    error = (
+                        "\n"
+                        "NOTE: Spyder *can't* set your selected Matplotlib "
+                        "backend because there is a previous backend already "
+                        "in use.\n\n"
+                        "Your backend will be {0}".format(previous_backend)
+                    )
                 del matplotlib
             # This covers other RuntimeError's
             else:
